@@ -19,13 +19,18 @@ as_q.default <- function(f, support = NULL, ..., n_grid = 10001) {
   }
 
   # Treate `f` as unknown q-function
-  q_f <- function(p) {f(p, ...)}
+  q_f <- function(p) {
+    f(p, ...)
+  }
 
   # Detect support
   support <- detect_support_q(q_f, format_support(support))
 
   p_f <- inversing(q_f, c(0, 1), n_grid = n_grid)
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   as_q(as_p(p_f, support, n_grid = n_grid))
 }
 
@@ -34,6 +39,9 @@ as_q.default <- function(f, support = NULL, ..., n_grid = 10001) {
 as_q.pdqr <- function(f, ...) {
   assert_pdqr_fun(f)
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   new_q(x = meta_x_tbl(f), type = meta_type(f))
 }
 
