@@ -34,7 +34,7 @@
 #'
 #' @examples
 #' # Type "discrete"
-#' my_dis <- new_d(data.frame(x = 1:4, prob = (1:4)/10), type = "discrete")
+#' my_dis <- new_d(data.frame(x = 1:4, prob = (1:4) / 10), type = "discrete")
 #' meta_x_tbl(form_tails(my_dis, level = 0.1))
 #' meta_x_tbl(
 #'   form_tails(my_dis, level = 0.35, method = "winsor", direction = "left")
@@ -52,7 +52,7 @@
 #' # Use `form_resupport()` and `as_q()` to remove different levels from both
 #' # directions. Here 0.1 level tail from left is removed, and 0.05 level from
 #' # right
-#' new_supp <- as_q(d_norm)(c(0.1, 1-0.05))
+#' new_supp <- as_q(d_norm)(c(0.1, 1 - 0.05))
 #' form_resupport(d_norm, support = new_supp)
 #'
 #' # Examples of robust mean
@@ -60,15 +60,17 @@
 #' x <- rcauchy(1000)
 #' d_x <- new_d(x, "continuous")
 #' summ_mean(d_x)
-#'   # Trimmed mean
+#' ## Trimmed mean
 #' summ_mean(form_tails(d_x, level = 0.1, method = "trim"))
-#'   # Winsorized mean
+#' ## Winsorized mean
 #' summ_mean(form_tails(d_x, level = 0.1, method = "winsor"))
-#'
 #' @export
 form_tails <- function(f, level, method = "trim", direction = "both") {
   assert_form_tails_args(f, level, method, direction)
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   switch(
     method,
     trim = tails_trim(f, level, direction),
@@ -76,6 +78,8 @@ form_tails <- function(f, level, method = "trim", direction = "both") {
   )
 }
 
+methods_tails <- c("trim", "winsor")
+
 tails_trim <- function(f, level, direction = "both") {
   is_all_trimmed <- ((direction %in% c("left", "right")) && (level == 1)) ||
     ((direction == "both") && (level == 0.5))
@@ -146,11 +150,9 @@ assert_form_tails_args <- function(f, level, method, direction) {
     stop_collapse("`level` should not be negative.")
   }
 
-  assert_type(method, is_string)
-  assert_in_set(method, c("trim", "winsor"))
+  assert_method(method, methods_tails)
 
-  assert_type(direction, is_string)
-  assert_in_set(direction, c("left", "right", "both"))
+  assert_method(direction, c("left", "right", "both"))
 
   if (direction == "both") {
     if (level > 0.5) {
@@ -161,7 +163,7 @@ assert_form_tails_args <- function(f, level, method, direction) {
   } else {
     if (level > 1) {
       stop_collapse(
-        '`level` should not be greater than 1 in case `direction` is one of ',
+        "`level` should not be greater than 1 in case `direction` is one of ",
         '"left" or "right".'
       )
     }
