@@ -26,19 +26,21 @@ as_pdqr_by_ref <- function(f) {
 
 # Custom constructors -----------------------------------------------------
 boolean_pdqr <- function(prob_true, pdqr_class) {
-  x_tbl <- data.frame(x = c(0, 1), prob = c(1-prob_true, prob_true))
+  x_tbl <- data.frame(x = c(0, 1), prob = c(1 - prob_true, prob_true))
 
   new_pdqr_by_class(pdqr_class)(x_tbl, "discrete")
 }
 
 
 # Handling list of pdqr-functions -----------------------------------------
-assert_f_list <- function(f_list, allow_numbers = FALSE) {
+assert_f_list <- function(f_list, allow_numbers = FALSE, f_list_name = NULL) {
   if (dont_assert()) {
     return(TRUE)
   }
 
-  f_list_name <- enbacktick(deparse(substitute(f_list)))
+  if (is.null(f_list_name)) {
+    f_list_name <- enbacktick(deparse(substitute(f_list)))
+  }
 
   if (missing(f_list)) {
     if (allow_numbers) {
@@ -83,11 +85,21 @@ assert_f_list <- function(f_list, allow_numbers = FALSE) {
 }
 
 compute_f_list_meta <- function(f_list) {
-  is_elem_pdqr <- vapply(f_list, is_pdqr_fun, logical(1))
+  # Note that it is assumed that `f_list` contains only pdqr-functions or single
+  # numbers. Currently it should be pretested with
+  # `assert_f_list(f_list, allow_numbers = TRUE)`
+  # Main reason behind it is a wish to avoid usage of possibly "computantionally
+  # expensive" `is_pdqr_fun()`.
+  is_elem_number <- vapply(f_list, is_single_number, logical(1))
+  is_elem_pdqr <- !is_elem_number
   type_vec <- vapply(f_list[is_elem_pdqr], meta_type, character(1))
 
   # Combined type is "discrete" only if all inputs are "discrete"
-  res_type <- if (all(type_vec == "discrete")) {"discrete"} else {"continuous"}
+  res_type <- if (all(type_vec == "discrete")) {
+    "discrete"
+  } else {
+    "continuous"
+  }
 
   # Combined class is the class of first pdqr-function (which should be present
   # due to call to `assert_f_list()`)
